==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/GridAnimationPhaseSettingsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridAnimationPhaseSettingsDescription } from "./GridAnimationPhaseSettingsDescription";
/**
 * @hidden
 */
export let GridAnimationPhaseSettingsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridAnimationPhaseSettingsDescriptionMetadata extends Base {
        static b(a) {
            if (GridAnimationPhaseSettingsDescriptionMetadata.a == null) {
                GridAnimationPhaseSettingsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridAnimationPhaseSettingsDescriptionMetadata.c(GridAnimationPhaseSettingsDescriptionMetadata.a);
            }
            if (a.k(GridAnimationPhaseSettingsDescriptionMetadata.a)) {
                return;
            }
            a.ab(GridAnimationPhaseSettingsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("DurationMilliseconds", "Number:int");
            a.item("HoldInitialMilliseconds", "Number:int");
            a.item("PerItemDelayMilliseconds", "Number:int");
            a.item("SubItemDurationMilliseconds", "Number:int");
            a.item("DesiredSubItemDurationMilliseconds", "Number:int");
            a.item("ShouldItemsFinishSimultaneously", "Boolean");
            a.item("EasingFunctionType", "ExportedType:string:GridEasingFunctionType");
            a.item("EasingFunctionType@names", "Linear;CubicInOut;ExponentialInOut;CircleInOut");
        }
        static d(a) {
            GridAnimationPhaseSettingsDescriptionMetadata.b(a);
            a.ad("GridAnimationPhaseSettings", () => new GridAnimationPhaseSettingsDescription());
            a.ac("GridAnimationPhaseSettings", GridAnimationPhaseSettingsDescriptionMetadata.a);
        }
    }
    GridAnimationPhaseSettingsDescriptionMetadata.$t = markType(GridAnimationPhaseSettingsDescriptionMetadata, 'GridAnimationPhaseSettingsDescriptionMetadata');
    GridAnimationPhaseSettingsDescriptionMetadata.a = null;
    return GridAnimationPhaseSettingsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/GridAnimationPhaseSettingsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridAnimationPhaseSettingsDescription } from "./GridAnimationPhaseSettingsDescription";
/**
 * @hidden
 */
export let GridAnimationPhaseSettingsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridAnimationPhaseSettingsDescriptionMetadata extends Base {
        static b(a) {
            if (GridAnimationPhaseSettingsDescriptionMetadata.a == null) {
                GridAnimationPhaseSettingsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridAnimationPhaseSettingsDescriptionMetadata.c(GridAnimationPhaseSettingsDescriptionMetadata.a);
            }
            if (a.k(GridAnimationPhaseSettingsDescriptionMetadata.a)) {
                return;
            }
            a.ac(GridAnimationPhaseSettingsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("DurationMilliseconds", "Number:int");
            a.item("HoldInitialMilliseconds", "Number:int");
            a.item("PerItemDelayMilliseconds", "Number:int");
            a.item("SubItemDurationMilliseconds", "Number:int");
            a.item("DesiredSubItemDurationMilliseconds", "Number:int");
            a.item("ShouldItemsFinishSimultaneously", "Boolean");
            a.item("EasingFunctionType", "ExportedType:string:GridEasingFunctionType");
            a.item("EasingFunctionType@names", "Linear;CubicInOut;ExponentialInOut;CircleInOut");
        }
        static d(a) {
            GridAnimationPhaseSettingsDescriptionMetadata.b(a);
            a.ae("GridAnimationPhaseSettings", () => new GridAnimationPhaseSettingsDescription());
            a.ad("GridAnimationPhaseSettings", GridAnimationPhaseSettingsDescriptionMetadata.a);
        }
    }
    GridAnimationPhaseSettingsDescriptionMetadata.$t = markType(GridAnimationPhaseSettingsDescriptionMetadata, 'GridAnimationPhaseSettingsDescriptionMetadata');
    GridAnimationPhaseSettingsDescriptionMetadata.a = null;
    return GridAnimationPhaseSettingsDescriptionMetadata;
})();
